import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { ReviewService } from '../../review.service';

@Component({
  moduleId: module.id,
  selector: 'comments',
  templateUrl: 'comment.component.html',
  styleUrls: ['comment.css'],
  providers: [ReviewService],
})
export class CommentComponent {
  @Output() error = new EventEmitter();
  @Output() updateSelectedReview = new EventEmitter();
  @Input() selectedReview: any;
  @Input() userInfo: string;
  @Input() accessToken: string = undefined;
  @Input() url: string;
  selectedComment: any;
  newComment: string;
  editedComment: any;
  isEditClicked: any;
  commentEmpty = false;
  private _reviewService: any;

  constructor(_reviewService: ReviewService) {
    this.isEditClicked = false;
    this._reviewService = _reviewService;
  }

  onEdit(comment: any) {
    this.isEditClicked = true;
    this.selectedComment = comment;
    this.editedComment = comment.value.Comment;
  }

  onSave() {
    if (this.editedComment) {
      let patchCommentBody = [
        {
          value: {
            UserInfo: this.selectedComment.value.UserInfo,
            Comment: this.editedComment,
            DateTime: this.selectedComment.value.DateTime,
          },
          path: '/Comments/' + this.selectedComment.key,
          op: 'replace',
        },
      ];
      this._reviewService
        .patchReview(
        this.url,
        this.selectedReview.ReviewId,
        patchCommentBody,
        this.userInfo,
        this.accessToken,
      )
        .subscribe(
        (data: any) => this.updateSelectedReview.emit(data),
        (error: any) => this.error.emit(error),
      );
      this.isEditClicked = false;
    } else {
      this.commentEmpty = true;
    }
  }

  onCancel() {
    this.newComment = '';
    this.isEditClicked = false;
    this.commentEmpty = false;
  }

  onComment() {
    if (this.newComment) {
      let postCommentBody = [
        {
          value: {
            UserInfo: this.userInfo,
            Comment: this.newComment,
          },
          path: '/Comments',
          op: 'add',
        },
      ];
      this._reviewService
        .patchReview(
        this.url,
        this.selectedReview.ReviewId,
        postCommentBody,
        this.userInfo,
        this.accessToken,
      )
        .subscribe(
        (data: any) => this.updateSelectedReview.emit(data),
        (error: any) => this.error.emit(error),
      );
      this.newComment = '';
    } else {
      this.commentEmpty = true;
    }
  }
}
