var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Input, Component, Output, EventEmitter } from '@angular/core';
import { ReviewService } from '../../review.service';
var ReviewList = (function () {
    function ReviewList(_reviewService) {
        this.statusChange = new EventEmitter();
        this.error = new EventEmitter();
        this.accessToken = undefined;
        this.canReview = false;
        this.canApprove = false;
        this.canSubmit = false;
        this._reviewService = _reviewService;
        this.isApproved = false;
        this.selectedReview = {
            Comments: {}
        };
    }
    ReviewList.prototype.onSelectReview = function (review) {
        if (this.reviewConfig.ReviewerList.length > 0) {
            this.canApprove =
                this.reviewConfig.ReviewerList.indexOf(this.userInfo) != -1;
            this.canReview = this.canApprove || review.CreatedBy === this.userInfo;
        }
        else {
            this.canReview = true;
            this.canApprove = false;
        }
        if (this.selectedReview.ReviewId != review.ReviewId) {
            this.updateReview(this.selectedReview);
            this.selectedReview = review;
            var index = this.selectedReview.Approvals.indexOf(this.userInfo.toLowerCase());
            if (index != -1) {
                this.isApproved = true;
            }
            else if (this.selectedReview.ReviewStatus != 'In Progress') {
                this.isApproved = true;
            }
            else {
                this.isApproved = false;
            }
        }
        this.canSubmit = this.checkCanSubmit();
    };
    ReviewList.prototype.checkCanSubmit = function () {
        if (this.selectedReview.Approvals.length >= this.reviewConfig.MinNoOfApprovals) {
            if (this.reviewConfig.MustBeApprovedBy.length === 0) {
                return true;
            }
            else {
                for (var i = 0; i < this.selectedReview.Approvals.length; i++) {
                    var approver = this.selectedReview.Approvals[i];
                    if (this.reviewConfig.MustBeApprovedBy.indexOf(approver) != -1) {
                        return true;
                    }
                }
                return false;
            }
        }
        else {
            return false;
        }
    };
    ReviewList.prototype.updateSelectedReview = function (data) {
        this.selectedReview = data;
    };
    ReviewList.prototype.onError = function (error) {
        this.error.emit(error);
    };
    ReviewList.prototype.onChangeReviewStatus = function (reviewStatus) {
        var _this = this;
        var ReviewStatus = reviewStatus;
        var patchReviewBody = [
            {
                value: ReviewStatus,
                path: '/ReviewStatus',
                op: 'replace'
            }
        ];
        this._reviewService
            .patchReview(this.url, this.selectedReview.ReviewId, patchReviewBody, this.userInfo, this.accessToken)
            .subscribe(function (data) {
            _this.statusChange.emit(data);
            _this.updateReview(data);
        }, function (error) { return _this.error.emit(error); });
    };
    ReviewList.prototype.onScheduleSubmit = function (data) {
        var _this = this;
        var patchReviewBody = [
            {
                value: data,
                path: '/SubmissionTime',
                op: 'replace'
            }
        ];
        this._reviewService
            .patchReview(this.url, this.selectedReview.ReviewId, patchReviewBody, this.userInfo, this.accessToken)
            .subscribe(function (data) {
            _this.updateReview(data);
        }, function (error) { return _this.error.emit(error); });
    };
    ReviewList.prototype.onApproval = function () {
        var _this = this;
        var patchReviewBody = [
            {
                value: this.userInfo.toLowerCase(),
                path: '/Approvals',
                op: 'add'
            }
        ];
        this._reviewService
            .patchReview(this.url, this.selectedReview.ReviewId, patchReviewBody, this.userInfo, this.accessToken)
            .subscribe(function (data) {
            _this.updateSelectedReview(data);
            _this.isApproved = true;
            _this.canSubmit = _this.checkCanSubmit();
        }, function (error) { return _this.error.emit(error); });
    };
    ReviewList.prototype.updateReview = function (data) {
        var _this = this;
        var index = this.reviews.findIndex(function (review) {
            return review.ReviewId == _this.selectedReview.ReviewId;
        });
        this.reviews[index] = data;
        this.selectedReview = data;
        this.statusChange.emit(data);
    };
    ReviewList.prototype.toDisplay = function () {
        return (this.selectedReview.SubmissionTime &&
            this.selectedReview.ReviewStatus == 'In Progress');
    };
    return ReviewList;
}());
__decorate([
    Output(),
    __metadata("design:type", Object)
], ReviewList.prototype, "statusChange", void 0);
__decorate([
    Output(),
    __metadata("design:type", Object)
], ReviewList.prototype, "error", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], ReviewList.prototype, "url", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], ReviewList.prototype, "userInfo", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], ReviewList.prototype, "accessToken", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], ReviewList.prototype, "reviews", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], ReviewList.prototype, "reviewConfig", void 0);
ReviewList = __decorate([
    Component({
        moduleId: module.id,
        selector: 'review-list',
        templateUrl: 'review-list.html',
        providers: [ReviewService],
        styleUrls: ['review-list.css']
    }),
    __metadata("design:paramtypes", [ReviewService])
], ReviewList);
export { ReviewList };
//# sourceMappingURL=review-list.component.js.map