import { Input, Component, Output, EventEmitter } from '@angular/core';
import { ReviewService } from '../../review.service';
import { ReviewModel } from '../../review.model';

@Component({
  moduleId: module.id,
  selector: 'review-list',
  templateUrl: 'review-list.html',
  providers: [ReviewService],
  styleUrls: ['review-list.css']
})
export class ReviewList {
  @Output() statusChange = new EventEmitter();
  @Output() error = new EventEmitter();
  @Input() url: any;
  @Input() userInfo: any;
  @Input() accessToken: string = undefined;
  @Input() reviews: any;
  @Input() reviewConfig: any;
  selectedReview: any;
  isApproved: boolean;
  canReview: boolean = false;
  canApprove: boolean = false;
  canSubmit: boolean = false;
  private _reviewService: any;
  constructor(_reviewService: ReviewService) {
    this._reviewService = _reviewService;
    this.isApproved = false;
    this.selectedReview = {
      Comments: {}
    };
  }

  onSelectReview(review: ReviewModel) {
    if (this.reviewConfig.ReviewerList.length > 0) {
      this.canApprove =
        this.reviewConfig.ReviewerList.indexOf(this.userInfo) != -1;
      this.canReview = this.canApprove || review.CreatedBy === this.userInfo;
    } else {
      this.canReview = true;
      this.canApprove = false;
    }
    if (this.selectedReview.ReviewId != review.ReviewId) {
      this.updateReview(this.selectedReview);
      this.selectedReview = review;
      let index = this.selectedReview.Approvals.indexOf(
        this.userInfo.toLowerCase()
      );
      if (index != -1) {
        this.isApproved = true;
      } else if (this.selectedReview.ReviewStatus != 'In Progress') {
        this.isApproved = true;
      } else {
        this.isApproved = false;
      }
    }
    this.canSubmit = this.checkCanSubmit();
  }

  checkCanSubmit() {
    if (
      this.selectedReview.Approvals.length >= this.reviewConfig.MinNoOfApprovals
    ) {
      if (this.reviewConfig.MustBeApprovedBy.length === 0) {
        return true;
      } else {
        for (let i = 0; i < this.selectedReview.Approvals.length; i++) {
          let approver = this.selectedReview.Approvals[i];
          if (this.reviewConfig.MustBeApprovedBy.indexOf(approver) != -1) {
            return true;
          }
        }
        return false;
      }
    } else {
      return false;
    }
  }

  updateSelectedReview(data: ReviewModel) {
    this.selectedReview = data;
  }

  onError(error: any) {
    this.error.emit(error);
  }

  onChangeReviewStatus(reviewStatus: string) {
    let ReviewStatus = reviewStatus;
    let patchReviewBody = [
      {
        value: ReviewStatus,
        path: '/ReviewStatus',
        op: 'replace'
      }
    ];
    this._reviewService
      .patchReview(
      this.url,
      this.selectedReview.ReviewId,
      patchReviewBody,
      this.userInfo,
      this.accessToken
      )
      .subscribe(
      (data: any) => {
        this.statusChange.emit(data);
        this.updateReview(data);
      },
      (error: any) => this.error.emit(error)
      );
  }

  onScheduleSubmit(data: string): void {
    let patchReviewBody = [
      {
        value: data,
        path: '/SubmissionTime',
        op: 'replace'
      }
    ];
    this._reviewService
      .patchReview(
      this.url,
      this.selectedReview.ReviewId,
      patchReviewBody,
      this.userInfo,
      this.accessToken
      )
      .subscribe(
      (data: any) => {
        this.updateReview(data);
      },
      (error: any) => this.error.emit(error)
      );
  }

  onApproval() {
    let patchReviewBody = [
      {
        value: this.userInfo.toLowerCase(),
        path: '/Approvals',
        op: 'add'
      }
    ];
    this._reviewService
      .patchReview(
      this.url,
      this.selectedReview.ReviewId,
      patchReviewBody,
      this.userInfo,
      this.accessToken
      )
      .subscribe(
      (data: any) => {
        this.updateSelectedReview(data);
        this.isApproved = true;
        this.canSubmit = this.checkCanSubmit();
      },
      (error: any) => this.error.emit(error)
      );
  }

  updateReview(data: ReviewModel) {
    let index = this.reviews.findIndex((review: any) => {
      return review.ReviewId == this.selectedReview.ReviewId;
    });
    this.reviews[index] = data;
    this.selectedReview = data;
    this.statusChange.emit(data);
  }

  toDisplay(): boolean {
    return (
      this.selectedReview.SubmissionTime &&
      this.selectedReview.ReviewStatus == 'In Progress'
    );
  }
}
