import { Input, Component, Output, EventEmitter, OnInit } from '@angular/core';
import { ReviewService } from '../../review.service';
import { ReviewModel } from '../../review.model';

@Component({
  selector: 'schedule-dropdown',
  templateUrl: 'schedule-dropdown.html',
  providers: [ReviewService],
  styleUrls: ['schedule-dropdown.css']
})

export class ScheduleDropdown implements OnInit {
  @Input() selectedReview: any;
  @Input() canSubmit: boolean;
  @Input() canReview: boolean;
  @Output() formSubmit = new EventEmitter();
  currentDateTime: Date;
  enteredDate: string;
  enteredTime: string;
  tickSymbol: string;
  minDate: string;
  maxDate: string;
  minTime: string;
  constructor() {
    this.selectedReview = {
      "Comments": {
      }
    };
    this.currentDateTime = new Date();
    this.minDate = this.currentDateTime.toISOString().slice(0, 10);
    this.maxDate = new Date((new Date(this.currentDateTime)).setMonth(this.currentDateTime.getMonth() + 1)).toISOString().slice(0, 10);
    this.minTime = "00:00";
    setInterval(() => {
      this.currentDateTime = new Date();
    }, 1000);
  }

  ngOnInit() {
    if (this.selectedReview.SubmissionTime) {
      this.tickSymbol = '\u2714';
      this.enteredDate = this.selectedReview.SubmissionTime.slice(0, 10);
      this.enteredTime = this.selectedReview.SubmissionTime.slice(11, 16);
      if (this.enteredDate.localeCompare(this.currentDateTime.toISOString().slice(0, 10)) == 0) {
        this.minTime = this.currentDateTime.toISOString().slice(11, 16);
      }
      else {
        this.minTime = "00:00";
      }
    }
  }

  onDropdownClick(e: any) {
    if (e.target.id !== "cancel") {
      e.stopPropagation();
    }
  }

  onScheduleSubmit(): void {
    const formData = this.enteredDate + "T" + this.enteredTime + ":00.000Z";
    if (formData.localeCompare(this.selectedReview.SubmissionTime) !== 0) {
      this.formSubmit.emit(formData);
    }
  }

  onDateInput(event: any): void {
    this.enteredDate = event.target.value;
    if (this.enteredDate.localeCompare(this.currentDateTime.toISOString().slice(0, 10)) == 0) {
      this.minTime = this.currentDateTime.toISOString().slice(11, 16);
    }
    else {
      this.minTime = "00:00";
    }
  }

  onTimeInput(event: any): void {
    this.enteredTime = event.target.value;
  }

  populateDate(): string {
    if (this.selectedReview.SubmissionTime)
      return this.selectedReview.SubmissionTime.slice(0, 10);
    else return "";
  }

  populateTime(): string {
    if (this.selectedReview.SubmissionTime)
      return this.selectedReview.SubmissionTime.slice(11, 16);
    else return "";
  }
}
