var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Input, Component, Output, EventEmitter } from '@angular/core';
import { MatSnackBar } from '@angular/material';
import { ReviewService } from './review.service';
import { ReviewModel } from './review.model';
var ReviewComponent = (function () {
    function ReviewComponent(_reviewService, snackBar) {
        this._reviewService = _reviewService;
        this.snackBar = snackBar;
        this.statusChange = new EventEmitter();
        this.error = new EventEmitter();
        this.accessToken = undefined;
        this.startKeyPrevious = {};
        this.startKeyNext = {};
        this.selectedTab = 0;
        this.limit = 10;
        this.reviewStatuses = ['In Progress', 'Submitted', 'Declined'];
        this.reviewConfig = {
            MinNoOfApprovals: 1,
            ReviewerList: [],
            MustBeApprovedBy: []
        };
        this.reviews = [];
        this.groupedReviews = {};
    }
    ReviewComponent.prototype.ngOnInit = function () {
        this.onSelectTab(this.selectedTab);
    };
    ReviewComponent.prototype.setReviews = function (reviews, isNext) {
        if (isNext === void 0) { isNext = false; }
        if (reviews.length) {
            if (!isNext) {
                this.startKeyPrevious = this.getExclusiveKey(reviews[0]);
                this.startKeyNext = this.getExclusiveKey(reviews[reviews.length - 1]);
            }
            else {
                this.startKeyNext = this.getExclusiveKey(reviews[0]);
                this.startKeyPrevious = this.getExclusiveKey(reviews[reviews.length - 1]);
            }
            this.reviews = reviews.map(function (review) {
                return new ReviewModel(review);
            });
            this.groupReview(this.reviews);
        }
    };
    ReviewComponent.prototype.groupReview = function (reviews) {
        var _this = this;
        this.groupedReviews = {};
        reviews.forEach(function (review) {
            if (_this.groupedReviews[review.ReviewStatus] &&
                _this.groupedReviews[review.ReviewStatus].length) {
                _this.groupedReviews[review.ReviewStatus].push(review);
            }
            else {
                _this.groupedReviews[review.ReviewStatus] = [review];
            }
        });
    };
    ReviewComponent.prototype.getExclusiveKey = function (review) {
        return {
            ReviewStatus: review.ReviewStatus,
            CreatedDateTime: review.CreatedDateTime,
            ReviewId: review.ReviewId
        };
    };
    ReviewComponent.prototype.onStatusChange = function (data) {
        this.statusChange.emit(data);
        this.updateReview(data);
    };
    ReviewComponent.prototype.onError = function (error) {
        this.error.emit(error);
    };
    ReviewComponent.prototype.updateReview = function (data) {
        var index = this.reviews.findIndex(function (review) {
            return review.ReviewId == data.ReviewId;
        });
        this.reviews[index] = data;
        this.setReviews(this.reviews);
    };
    ReviewComponent.prototype.onSelectTab = function (event) {
        var _this = this;
        this.selectedTab = event;
        this.groupedReviews = {};
        this._reviewService
            .getReview(this.url, this.userInfo, this.reviewStatuses[event], this.limit, false, null, this.accessToken)
            .subscribe(function (data) {
            _this.isButtonEnabled(data, false, false);
            _this.setReviews(data.Items);
        }, function (error) { return _this.error.emit(error); });
    };
    ReviewComponent.prototype.previousClicked = function () {
        var _this = this;
        var reviewStatus = this.reviewStatuses[this.selectedTab], isNext = true;
        this._reviewService
            .getReview(this.url, this.userInfo, reviewStatus, this.limit, isNext, JSON.stringify(this.startKeyPrevious), this.accessToken)
            .subscribe(function (data) {
            _this.isButtonEnabled(data, false, true);
            _this.setReviews(data.Items, isNext);
        }, function (error) { return _this.error.emit(error); });
    };
    ReviewComponent.prototype.nextClicked = function () {
        var _this = this;
        var reviewStatus = this.reviewStatuses[this.selectedTab], isNext = false;
        this._reviewService
            .getReview(this.url, this.userInfo, reviewStatus, this.limit, isNext, JSON.stringify(this.startKeyNext), this.accessToken)
            .subscribe(function (data) {
            _this.isButtonEnabled(data, true, false);
            _this.setReviews(data.Items, isNext);
        }, function (error) { return _this.error.emit(error); });
    };
    ReviewComponent.prototype.isButtonEnabled = function (data, nextClicked, previousClicked) {
        if (nextClicked === void 0) { nextClicked = false; }
        if (previousClicked === void 0) { previousClicked = false; }
        this.nextButtonEnable = false;
        this.previousButtonEnable = false;
        if (nextClicked) {
            this.previousButtonEnable = true;
            if (data.LastEvaluatedKey) {
                this.nextButtonEnable = true;
            }
        }
        else if (previousClicked) {
            this.nextButtonEnable = true;
            if (data.LastEvaluatedKey) {
                this.previousButtonEnable = true;
            }
        }
        else {
            if (data.LastEvaluatedKey) {
                this.nextButtonEnable = true;
            }
        }
    };
    return ReviewComponent;
}());
__decorate([
    Output(),
    __metadata("design:type", Object)
], ReviewComponent.prototype, "statusChange", void 0);
__decorate([
    Output(),
    __metadata("design:type", Object)
], ReviewComponent.prototype, "error", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], ReviewComponent.prototype, "url", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], ReviewComponent.prototype, "userInfo", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], ReviewComponent.prototype, "reviewConfig", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], ReviewComponent.prototype, "accessToken", void 0);
ReviewComponent = __decorate([
    Component({
        moduleId: module.id,
        selector: 'review-component',
        templateUrl: 'review.html',
        styleUrls: ['review.css'],
        providers: [ReviewService]
    }),
    __metadata("design:paramtypes", [ReviewService,
        MatSnackBar])
], ReviewComponent);
export { ReviewComponent };
//# sourceMappingURL=review.component.js.map