import { Input, OnInit, Component, Output, EventEmitter } from '@angular/core';
import { MatSnackBar } from '@angular/material';
import { ReviewService } from './review.service';
import { ReviewModel } from './review.model';

@Component({
  moduleId: module.id,
  selector: 'review-component',
  templateUrl: 'review.html',
  styleUrls: ['review.css'],
  providers: [ReviewService]
})
export class ReviewComponent implements OnInit {
  @Output() statusChange = new EventEmitter();
  @Output() error = new EventEmitter();
  @Input() url: any;
  @Input() userInfo: string;
  @Input() reviewConfig: any;
  @Input() accessToken: string = undefined;
  reviews: any;
  startKeyPrevious: any = {};
  startKeyNext: any = {};
  selectedTab = 0;
  limit = 10;
  groupedReviews: any;
  nextButtonEnable: boolean;
  previousButtonEnable: boolean;
  reviewStatuses = ['In Progress', 'Submitted', 'Declined'];

  constructor(
    private _reviewService: ReviewService,
    public snackBar: MatSnackBar
  ) {
    this.reviewConfig = {
      MinNoOfApprovals: 1,
      ReviewerList: [],
      MustBeApprovedBy: []
    };
    this.reviews = [];
    this.groupedReviews = {};
  }

  ngOnInit() {
    this.onSelectTab(this.selectedTab);
  }

  setReviews(reviews: any, isNext = false) {
    if (reviews.length) {
      if (!isNext) {
        this.startKeyPrevious = this.getExclusiveKey(reviews[0]);
        this.startKeyNext = this.getExclusiveKey(reviews[reviews.length - 1]);
      } else {
        this.startKeyNext = this.getExclusiveKey(reviews[0]);
        this.startKeyPrevious = this.getExclusiveKey(
          reviews[reviews.length - 1]
        );
      }
      this.reviews = reviews.map((review: any) => {
        return new ReviewModel(review);
      });
      this.groupReview(this.reviews);
    }
  }

  groupReview(reviews: any) {
    this.groupedReviews = {};
    reviews.forEach((review: any) => {
      if (
        this.groupedReviews[review.ReviewStatus] &&
        this.groupedReviews[review.ReviewStatus].length
      ) {
        this.groupedReviews[review.ReviewStatus].push(review);
      } else {
        this.groupedReviews[review.ReviewStatus] = [review];
      }
    });
  }

  getExclusiveKey(review: any) {
    return {
      ReviewStatus: review.ReviewStatus,
      CreatedDateTime: review.CreatedDateTime,
      ReviewId: review.ReviewId
    };
  }

  onStatusChange(data: any) {
    this.statusChange.emit(data);
    this.updateReview(data);
  }

  onError(error: any) {
    this.error.emit(error);
  }

  updateReview(data: ReviewModel) {
    let index = this.reviews.findIndex((review: any) => {
      return review.ReviewId == data.ReviewId;
    });
    this.reviews[index] = data;
    this.setReviews(this.reviews);
  }

  onSelectTab(event: any) {
    this.selectedTab = event;
    this.groupedReviews = {};
    this._reviewService
      .getReview(
        this.url,
        this.userInfo,
        this.reviewStatuses[event],
        this.limit,
        false,
        null,
        this.accessToken
      )
      .subscribe(
        (data: any) => {
          this.isButtonEnabled(data, false, false);
          this.setReviews(data.Items);
        },
        (error: any) => this.error.emit(error)
      );
  }

  previousClicked() {
    const reviewStatus = this.reviewStatuses[this.selectedTab],
      isNext = true;
    this._reviewService
      .getReview(
        this.url,
        this.userInfo,
        reviewStatus,
        this.limit,
        isNext,
        JSON.stringify(this.startKeyPrevious),
        this.accessToken
      )
      .subscribe(
        (data: any) => {
          this.isButtonEnabled(data, false, true);
          this.setReviews(data.Items, isNext);
        },
        (error: any) => this.error.emit(error)
      );
  }

  nextClicked() {
    const reviewStatus = this.reviewStatuses[this.selectedTab],
      isNext = false;
    this._reviewService
      .getReview(
        this.url,
        this.userInfo,
        reviewStatus,
        this.limit,
        isNext,
        JSON.stringify(this.startKeyNext),
        this.accessToken
      )
      .subscribe(
        (data: any) => {
          this.isButtonEnabled(data, true, false);
          this.setReviews(data.Items, isNext);
        },
        (error: any) => this.error.emit(error)
      );
  }

  isButtonEnabled(data: any, nextClicked = false, previousClicked = false) {
    this.nextButtonEnable = false;
    this.previousButtonEnable = false;
    if (nextClicked) {
      this.previousButtonEnable = true;
      if (data.LastEvaluatedKey) {
        this.nextButtonEnable = true;
      }
    } else if (previousClicked) {
      this.nextButtonEnable = true;
      if (data.LastEvaluatedKey) {
        this.previousButtonEnable = true;
      }
    } else {
      if (data.LastEvaluatedKey) {
        this.nextButtonEnable = true;
      }
    }
  }
}
